==> kdewebdev-3.3.2.tar.bz2: kdewebdev-3.3.2/quanta/project/uploadprofilespage.ui.h <==
/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
/***********************************************************************
    begin                : Wed Jul 28 2004
    copyright            : (C) 2004 by Andras Mantia <amantia@kde.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "projectupload.h"

void UploadProfilesPage::buttonEditProfiles_clicked()
{
   ProjectUpload* dlg = new ProjectUpload(KURL(), true);
   dlg->exec();
   profileLabel->setText(dlg->defaultProfile());
   delete dlg;
}

==> kdewebdev-3.5.10.tar.bz2: kdewebdev-3.5.10/quanta/project/uploadprofilespage.ui.h <==
/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
/***********************************************************************
    begin                : Wed Jul 28 2004
    copyright            : (C) 2004 by Andras Mantia <amantia@kde.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "projectupload.h"

void UploadProfilesPage::buttonEditProfiles_clicked()
{
   ProjectUpload* dlg = new ProjectUpload(KURL(), "", true);
   dlg->exec();
   profileLabel->setText(dlg->defaultProfile());
   delete dlg;
}
